Stdio Mask
======

A cross-platform Python module for entering passwords to a stdio terminal and displaying a **** mask, which getpass cannot do.

Installation
------------

To install with pip, run:

    pip install stdiomask

Quickstart Guide
----------------

TODO - fill this in later

Contribute
----------

If you'd like to contribute to Stdio Mask, check out https://github.com/asweigart/stdiomask
